@@ -13,16 +13,17 @@
 #' @param file Optional .csv file to write to. If it is specified, individual
 #' cause of death distribution will be saved to the file.
 #' @param top Number of top causes to display on screen.
+#' @param id ID of specific death to display on screen.
 #' @param \dots Not used.
-#' @return \item{id}{ the ID of the deaths.} 
+#' @return \item{id.all}{ all IDs of the deaths.} 
 #' \item{indiv}{ individual Cause of Death distribution matrix.} 
 #' \item{csmf}{ CSMF distribution and confidence interval for each cause.} 
 #' \item{csmf.ordered}{ CSMF distribution and confidence interval for each cause, ordered by mean.} 
 #' \item{condprob}{ Conditional probability matrix and confidence intervals.}
-#' \item{useProbbase}{Component of \code{"insilico"} object.}
+#' \item{updateCondProb}{Component of \code{"insilico"} object.}
 #' \item{keepProbbase.level}{Component of \code{"insilico"} object.}
 #' \item{datacheck}{Component of \code{"insilico"} object.}
-#' \item{length.sim}{Component of \code{"insilico"} object.}
+#' \item{Nsim}{Component of \code{"insilico"} object.}
 #' \item{thin}{Component of \code{"insilico"} object.} \item{burnin}{Component
 #' of \code{"insilico"} object.} 
 #' \item{jump.scale}{Component of \code{"insilico"} object.}
@@ -44,7 +45,7 @@
 #' \dontrun{
 #' # load sample data together with sub-population list
 #' data(RandomVA1)
-#' # extract INterVA style input data
+#' # extract InterVA style input data
 #' data <- RandomVA1$data
 #' # extract sub-population information. 
 #' # The groups are "HIV Positive", "HIV Negative" and "HIV status unknown".
@@ -52,15 +53,15 @@
 #' 
 #' # run without subpopulation
 #' fit1<- insilico( data, subpop = NULL, 
-#'               length.sim = 400, burnin = 200, thin = 10 , seed = 1,
+#'               Nsim = 400, burnin = 200, thin = 10 , seed = 1,
 #'               external.sep = TRUE, keepProbbase.level = TRUE)
 #' summary(fit1)
 #' summary(fit1, top = 10)
 #' }
 #' @export summary.insilico
 summary.insilico <- function(object, CI.csmf = 0.95, CI.cond = 0.95, 
-				  file = NULL, top = 10, ...){
-	id <- object$id
+				  file = NULL, top = 10, id = NULL, ...){
+	id.all <- object$id
 	prob <- object$indiv.prob
 	csmf <- object$csmf
 	if(is.null(object$conditional.probs)){
@@ -77,7 +78,7 @@ summary.insilico <- function(object, CI.csmf = 0.95, CI.cond = 0.95,
 		}
 	}
 
-	indiv <- cbind(id, prob)
+	indiv <- cbind(id.all, prob)
 	## write individual COD distribution to file
 	if(!is.null(file)){
 		write.csv(indiv, file = file, row.names = FALSE)
@@ -151,15 +152,28 @@ summary.insilico <- function(object, CI.csmf = 0.95, CI.cond = 0.95,
 		subpop_counts <- NULL
 	}
 
-	out <- list( id = id, 
+	if(!is.null(id)){
+		if(!id %in% rownames(object$indiv.prob)){
+			stop("Invalid ID, not exist in data.")
+		}
+		whichtoprint <- order(object$indiv.prob[id, ], decreasing = TRUE)[1:top]
+		indiv.prob <- cbind(object$indiv.prob[id, whichtoprint], 
+							object$indiv.prob.lower[id, whichtoprint], 
+							object$indiv.prob.median[id, whichtoprint], 
+							object$indiv.prob.upper[id, whichtoprint])
+		colnames(indiv.prob) = c("Mean", "Lower", "Median", "Upper")	
+	}else{
+		indiv.prob <- NULL
+	}
+	out <- list( id.all = id.all, 
 				 indiv = indiv, 
 				 csmf = csmf.out, 
 				 csmf.ordered = csmf.out.ordered,
 				 condprob = cond.out, 				
-				 useProbbase = object$useProbbase, 
+				 updateCondProb = object$updateCondProb, 
 				 keepProbbase.level = object$keepProbbase.level, 
 				 datacheck = object$datacheck,
-				 length.sim = object$length.sim, 
+				 Nsim = object$Nsim, 
 				 thin = object$thin, 
 				 burnin = object$burnin, 
 				 HIV = object$HIV, 
@@ -170,7 +184,10 @@ summary.insilico <- function(object, CI.csmf = 0.95, CI.cond = 0.95,
 				 trunc.min = object$trunc.min, 
 				 trunc.maobject = object$trunc.max, 
 			     subpop_counts = subpop_counts,
-				 showTop = top)
+				 showTop = top, 
+				 id = id, 
+				 indiv.prob = indiv.prob, 
+				 indiv.CI = object$indiv.CI)
 	class(out) <- "insilico_summary"
 	return(out)
 }
